<?php

namespace Drupal\entity_workflow\EventSubscriber;

use Drupal\entity_workflow\Event\EntityWorkflowEvents;
use Drupal\entity_workflow\Event\InitiateTransitionEvent;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

class EntityWorkflowEventSubscriber implements EventSubscriberInterface {

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    $events = [
      EntityWorkflowEvents::INITIATE_TRANSITION => ['onInitiateTransaction', 0],
    ];
    return $events;
  }

  /**
   * Applies the workflow transition
   *
   * @param \Drupal\entity_workflow\Event\InitiateTransitionEvent $event
   *   The initiate transition event.
   */
  public function onInitiateTransaction(InitiateTransitionEvent $event) {
    $entity = $event->getEntity();

    $workflow_field = entity_workflow_get_field($entity, $event->getWorkflowId());
    $workflow_field->applyTransitionById($event->getTransitionId(), $event->getTransitionLog());
    $entity->_entityWorkflowEnforceNoNewRevision = TRUE;
    $entity->save();
  }

}
